@@ -46,10 +46,12 @@ def main():
     add('-namespace')
     add('-only_data')
     add('-php_validate')
+    add('-validate_allow_different_virtual_method')
     add('-test_script')
     add('-test_script_args')
     add('-auto_registration')
     add('-generate_ref_counter')
+    add('-user_includes')
 
     print(args)
 
