@@ -1,3 +1,4 @@
+from mlc_tools.module_cpp.generator_ref_counter import GeneratorRefCounter
 from ..base.generator import GeneratorBase
 from .generator_data_storage import GeneratorDataStorage
 from ..base.generator_visitor import GeneratorVisitor
@@ -16,5 +17,6 @@ class Generator(GeneratorBase):
         GeneratorDataStorage().generate(model)
         GeneratorPredefinedFiles().generate(model)
         GeneratorVisitor().generate(model, True)
-        GeneratorOperatorEquals().generate(model)
         GeneratorObserver().generate(model)
+        GeneratorRefCounter().generate(model)
+        GeneratorOperatorEquals().generate(model)
