@@ -63,6 +63,15 @@ class RegexPatternPython(object):
     }
     ''', ['list_do_if']),
 
+        # FROM:
+        #   list_do(this->test_list_lambda, (value :> some_action);
+        (re.compile(r'list_do\(([\w\d\-\>\.\[\]]+),\s*\((\w+)\s*:>\s*(.+)\)\)'), r'''
+    for __index__ in range(len(\1)):
+    {
+        \2 = \1[__index__]
+        \3
+    }''', ['list_do']),
+
         (re.compile(r'\bDataStorage::shared\(\).get<(\w+)>'), r'DataStorage::shared().get\1', ['DataStorage::shared']),
         (re.compile(r'\bFactory::(.+)<\w+>'), r'Factory.\1', ['Factory::']),
         (re.compile(r'\bfor\s*\(\s*\w+[\s&\*]*(\w+)\s*:\s*(.+)\s*\)'), r'for \1 in \2:', ['for']),
@@ -132,7 +141,11 @@ class RegexPatternPython(object):
         (re.compile(r'([\w\.]+?)\s*==\s*False'), r'not (\1)', ['False']),
         (re.compile(r'\bstrTo<(\w+)>\((.+?)\)'), r'strTo(\2, \1)', ['strTo']),
         (re.compile(r'\btoStr\((.+?)\)'), r'str(\1)', ['toStr']),
-        (re.compile(r'(\w+)<(.+)>\((.+?)\)'), r'\1(\3, \2)', ['<']),
+
+        # Template arguments
+        (re.compile(r'(\w+)<(.+?)>\(\)'), r'\1(\2)', ['<']),
+        (re.compile(r'(\w+)<(.+?)>\((.+?)\)'), r'\1(\3, \2)', ['<']),
+
         (re.compile(r'std::strcat\((.+?),\s*(.+?)\)'), r'((\1)+(\2))', ['std::strcat']),
         (re.compile(r'\.at\((.*?)\)'), r'[\1]', ['at']),
 
