@@ -96,7 +96,7 @@ class Writer(WriterBase):
                 value = "0"
             if type_ == "float":
                 value = "0"
-            if type_ == "uint":
+            if type_ in ["uint", 'unsigned']:
                 value = "0"
             if type_ == "bool":
                 value = "False"
@@ -105,7 +105,7 @@ class Writer(WriterBase):
             if type_ == "map":
                 value = "{}"
             else:
-                if self.model.has_class(obj.type):
+                if self.model.has_class(obj.type) and self.current_class.name != obj.type:
                     value = obj.type + '()'
                     tabs = ' ' * (4 if obj.is_static else 8)
                     imports.append(f'from .{obj.type} import {obj.type}')
